@@ -1,10 +1,10 @@
 #' Extract selected time series from a gts object
-#' 
+#'
 #' The time series from selected levels of a hierarchical/grouped time series
 #' or a forecasted hierarchical/grouped time series are returned as a
 #' multivariate time series.
-#' 
-#' 
+#'
+#'
 #' @param y An object of class \code{{gts}}.
 #' @param levels Integer(s) or string(s) giving the specified level(s).
 #' @param forecasts If \code{y} contains forecasts and historical data, then
@@ -14,10 +14,10 @@
 #' @seealso \code{\link[hts]{allts}}
 #' @keywords ts
 #' @examples
-#' 
+#'
 #' aggts(htseg1, levels = c(0, 2))
 #' aggts(infantgts, levels = "State")
-#' 
+#'
 #' @export aggts
 aggts <- function(y, levels, forecasts = TRUE) {
   # 1. Display all time series from top to bottom.
@@ -60,7 +60,7 @@ aggts <- function(y, levels, forecasts = TRUE) {
   }
 
   # A function to aggregate the bts
-  rSum <- function(x) rowsum(t(y$bts), gmat[x, ], reorder = FALSE, na.rm = TRUE)
+  rSum <- function(x) rowsum(t(y$bts), gmat[x, ], reorder = FALSE)
 
   ally <- lapply(levels, rSum)
   # Convert lists to matrices
@@ -80,12 +80,12 @@ aggts <- function(y, levels, forecasts = TRUE) {
 
 
 #' Extract all time series from a gts object
-#' 
+#'
 #' The time series from all levels of a hierarchical/grouped time series or a
 #' forecasted hierarchical/grouped time series are returned as a multivariate
 #' time series.
-#' 
-#' 
+#'
+#'
 #' @param y An object of class \code{\link[hts]{gts}}.
 #' @param forecasts If \code{y} contains forecasts and historical data, then
 #' \code{forecasts} indicates whether to return the forecasts or the historical
@@ -94,9 +94,9 @@ aggts <- function(y, levels, forecasts = TRUE) {
 #' @seealso \code{\link[hts]{aggts}}
 #' @keywords ts
 #' @examples
-#' 
+#'
 #' allts(htseg1)
-#' 
+#'
 #' @export allts
 allts <- function(y, forecasts = TRUE) {
   if (!is.gts(y)) {
