@@ -1,8 +1,8 @@
 #' Plot grouped or hierarchical time series
-#' 
+#'
 #' Method for plotting grouped or hierarchical time series and their forecasts.
-#' 
-#' 
+#'
+#'
 #' @param x An object of class \code{\link[hts]{gts}}.
 #' @param include Number of values from historical time series to include in
 #' the plot of forecasted group/hierarchical time series.
@@ -22,15 +22,16 @@
 #' @keywords hplot
 #' @method plot gts
 #' @examples
-#' 
+#'
 #' plot(htseg1, levels = c(0, 2))
 #' plot(infantgts, include = 10, levels = "State")
-#' plot(infantgts, include = 10, levels = "State", 
+#' plot(infantgts, include = 10, levels = "State",
 #'     col = colours()[100:107], lty = 1:8, color_lab = TRUE)
-#' 
+#'
 #' @export
 #' @export plot.gts
-plot.gts <- function(x, include, levels, labels = TRUE, 
+
+plot.gts <- function(x, include, levels, labels = TRUE,
                      col = NULL, color_lab = FALSE, ...) {
   # Do plotting
   #
@@ -101,22 +102,14 @@ plot.gts <- function(x, include, levels, labels = TRUE,
     }
     if(!is.null(x$histy)) {
       ylim <- range(histx[, series], fcasts[, series], na.rm = TRUE)
-      if (labels) {
-        strlabels <- max(strwidth(x$labels[levels], units = "figure"))
-        xlim <- range(time(histx)[1L] - strlabels, time(fcasts),
-                      na.rm = TRUE)
-      } else {
-        xlim <- range(time(histx), time(fcasts), na.rm = TRUE)
-      }
+      xlim <- range(time(histx), time(fcasts), na.rm = TRUE)
     } else {
       ylim <- range(histx[, series], na.rm = TRUE)
-      if (labels) {
-        strlabels <- max(strwidth(x$labels[levels], units = "figure"))
-        timex <- time(histx)
-        xlim <- range(timex[1L] - strlabels, timex, na.rm = TRUE)
-      } else {
-        xlim <- range(time(histx), na.rm = TRUE)
-      }
+      xlim <- range(time(histx), na.rm=TRUE)
+    }
+    if (labels) {
+      strlabels <- max(strwidth(x$labels[levels], units = "figure"))
+      xlim[1L] <- xlim[1L] - strlabels * diff(xlim) / par()$fin[1]
     }
     if (is.null(dots.list$xlim)) {
       plot(histx[, series, drop = FALSE], col = cols, xlim = xlim, ylim = ylim,
@@ -145,7 +138,7 @@ plot.gts <- function(x, include, levels, labels = TRUE,
       } else {
         lab_col <- par()$fg
       }
-      text(x = stats::tsp(histx)[1L] + 0.1, y = histx[1L, series] + 0.2,
+      text(x = stats::tsp(histx)[1L] - 0.02*diff(xlim), y = histx[1L, series],
            labels = unlist(x$labels[levels][i]),
            cex = 0.9, adj = 1, col = lab_col)
     }
